package net.knarcraft.ffmpegconverter.converter.module.mapping;

import net.knarcraft.ffmpegconverter.container.FFMpegCommand;
import net.knarcraft.ffmpegconverter.converter.module.ConverterModule;
import net.knarcraft.ffmpegconverter.streams.SubtitleStream;
import net.knarcraft.ffmpegconverter.streams.VideoStream;
import net.knarcraft.ffmpegconverter.utility.FFMpegHelper;
import org.jetbrains.annotations.NotNull;

/**
 * A module for burning the selected subtitle into a video
 */
public class BurnSubtitleModule implements ConverterModule {

    private final SubtitleStream subtitleStream;
    private final VideoStream videoStream;
    private final boolean mapVideo;

    /**
     * Instantiates a subtitle burning converter
     *
     * @param subtitleStream <p>The subtitle stream to burn to a video stream</p>
     * @param videoStream    <p>The video stream to burn into</p>
     * @param mapVideo       <p>Whether to map the given video stream (only disable if mapped elsewhere)</p>
     */
    public BurnSubtitleModule(@NotNull SubtitleStream subtitleStream, @NotNull VideoStream videoStream,
                              boolean mapVideo) {
        this.subtitleStream = subtitleStream;
        this.videoStream = videoStream;
        this.mapVideo = mapVideo;
    }

    @Override
    public void addArguments(@NotNull FFMpegCommand command) {
        if (mapVideo) {
            FFMpegHelper.mapStream(command, videoStream);
        }

        if (subtitleStream.getIsImageSubtitle()) {
            command.addOutputFileOption("-filter_complex",
                    String.format("[%d:%d]scale=width=%d:height=%d,crop=w=%d:h=%d:x=0:y=out_h[sub];[%d:%d][sub]overlay",
                            subtitleStream.getInputIndex(), subtitleStream.getAbsoluteIndex(), videoStream.getWidth(),
                            videoStream.getHeight(), videoStream.getWidth(), videoStream.getHeight(),
                            videoStream.getInputIndex(), videoStream.getAbsoluteIndex()));
            command.addOutputFileOption("-profile:v", "baseline");
        } else {
            String safeFileName = FFMpegHelper.escapeSpecialCharactersInFileName(
                    command.getInputFiles().get(subtitleStream.getInputIndex()));
            String subtitleCommand = String.format("subtitles='%s':si=%d", safeFileName,
                    subtitleStream.getRelativeIndex());
            command.addOutputFileOption("-vf", subtitleCommand);
        }
    }

}
