package net.knarcraft.ffmpegconverter.converter.module.mapping;

import net.knarcraft.ffmpegconverter.container.FFMpegCommand;
import net.knarcraft.ffmpegconverter.converter.module.ConverterModule;
import net.knarcraft.ffmpegconverter.streams.VideoStream;
import net.knarcraft.ffmpegconverter.utility.FFMpegHelper;
import org.jetbrains.annotations.NotNull;

import java.util.List;

public class NthVideoStreamModule implements ConverterModule {

    private final int n;
    private final List<VideoStream> allStreams;

    /**
     * Instantiates a new n-th video stream module
     *
     * @param allStreams <p>All available streams</p>
     * @param n          <p>The index of the stream the user wants</p>
     */
    public NthVideoStreamModule(@NotNull List<VideoStream> allStreams, int n) {
        this.allStreams = allStreams;
        this.n = n;
    }

    @Override
    public void addArguments(@NotNull FFMpegCommand command) {
        VideoStream videoStream = FFMpegHelper.getNthSteam(this.allStreams, this.n);
        if (videoStream != null) {
            FFMpegHelper.mapStream(command, videoStream);
        } else {
            throw new IllegalArgumentException("Selected video stream does not exist.");
        }
    }

}
