package net.knarcraft.ffmpegconverter.property;

/**
 * A representation for different preferences related to minimal subtitles
 *
 * <p>Minimal subtitles are also referred to as partial subtitles or signs and songs. For Japanese media, they are aimed
 * at users that understand the spoken language, but struggles with reading, or when things are said too fast or in an
 * odd rhythm (singing). In american movies, some partial subtitles only translate non-english spoken language. Some
 * dubbed movies have subtitles that only cover signs, text or logos in the original language.</p>
 */
public enum MinimalSubtitlePreference {

    /**
     * Only map minimal subtitles
     */
    REQUIRE,

    /**
     * Prefer minimal subtitles when available
     */
    PREFER,

    /**
     * Don't do any changes in sorting based on minimal subtitles
     */
    NO_PREFERENCE,

    /**
     * Avoid minimal subtitles, unless it's the only available choice
     */
    AVOID,

    /**
     * Don't include minimal subtitles, no matter what
     */
    REJECT,

}
