package net.knarcraft.ffmpegconverter.utility;

import org.jetbrains.annotations.NotNull;

import java.io.BufferedWriter;
import java.io.IOException;
import java.io.OutputStreamWriter;

/**
 * A class which helps with outputting information
 */
public final class OutputUtil {

    private static final BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(System.out));
    private static boolean debug;

    private OutputUtil() {

    }

    /**
     * Sets whether to show debug messages
     *
     * @param debug <p>The debug message to show.</p>
     */
    public static void setDebug(boolean debug) {
        OutputUtil.debug = debug;
    }

    /**
     * Prints something and a newline to the commandline efficiently
     *
     * @param input <p>The text to print.</p>
     */
    public static void println(@NotNull String input) {
        if (!input.isEmpty()) {
            try {
                writer.write(input);
            } catch (IOException e) {
                System.out.print(input);
            }
        }
        println();
    }

    /**
     * Prints a string
     *
     * @param input <p>The string to print.</p>
     */
    public static void print(@NotNull String input) {
        try {
            writer.write(input);
            writer.flush();
        } catch (IOException e) {
            System.out.print(input);
        }
    }


    /**
     * Prints a newline
     */
    public static void println() {
        try {
            writer.newLine();
            writer.flush();
        } catch (IOException e) {
            System.out.println();
        }
    }

    /**
     * Closes the writer
     *
     * @throws IOException <p>If the writer cannot be closed.</p>
     */
    public static void close() throws IOException {
        writer.close();
    }

    /**
     * Prints a message if debug messages should be shown
     *
     * @param message <p>The debug message to show.</p>
     */
    public static void printDebug(@NotNull String message) {
        if (debug) {
            println(message);
        }
    }

}
